@@ -36,6 +36,9 @@ to.period <- to_period <- function(x, period='months', k=1, indexAt=NULL, name=N
   xo <- x
   x <- try.xts(x)
 
+  if(NROW(x)==0 || NCOL(x)==0)
+    stop(sQuote("x")," contains no data")
+
   if(any(is.na(x))) {
     x <- na.omit(x)
     warning("missing values removed from data")
@@ -157,7 +160,7 @@ function(x,drop.time=TRUE,name,...)
   return(x)
 }
 `to.monthly` <-
-function(x,indexAt='yearmon',drop.time=FALSE,name,...)
+function(x,indexAt='yearmon',drop.time=TRUE,name,...)
 {
   if(missing(name)) name <- deparse(substitute(x))
   x <- to.period(x,'months',indexAt=indexAt,name=name,...)
@@ -165,7 +168,7 @@ function(x,indexAt='yearmon',drop.time=FALSE,name,...)
   return(x)
 }
 `to.quarterly` <-
-function(x,indexAt='yearqtr',drop.time=FALSE,name,...)
+function(x,indexAt='yearqtr',drop.time=TRUE,name,...)
 {
   if(missing(name)) name <- deparse(substitute(x))
   x <- to.period(x,'quarters',indexAt=indexAt,name=name,...)
@@ -183,14 +186,20 @@ function(x,drop.time=TRUE,name,...)
 `.drop.time` <-
 function(x) {
   # function to remove HHMMSS portion of time index
-  if(!inherits(x,"its")) {
-    x <- as.xts(x)
-    current.indexClass <- indexClass(x)
-    if(current.indexClass[1] == 'POSIXt')
-      indexClass(x) <- "Date"
-      #reclass(x)
-    x
-  } else x
+  xts.in <- is.xts(x)  # is the input xts?
+  if(!xts.in)          # if not, try to convert to xts
+    x <- try.xts(x, error=FALSE)
+  if(is.xts(x)) {
+    # if x is xts, drop HHMMSS from index
+    if(any(indexClass(x)=='POSIXt')) {
+      indexClass(x) <- "Date"  # set indexClass to Date
+    }
+    # force conversion, even if we didn't set indexClass to Date
+    # because indexAt yearmon/yearqtr won't drop time from index
+    index(x) <- index(x)
+    if(xts.in)  x    # if input already was xts
+    else reclass(x)  # if input wasn't xts, but could be converted
+  } else  x          # if input wasn't xts, and couldn't be converted
 }
 `by.period` <-
 function(x, FUN, on=Cl, period="days", k=1, fill=na.locf, ...) {
